==========
GrapeFruit
==========

.. image:: https://img.shields.io/pypi/v/grapefruit.svg?style=flat
   :target: https://pypi.python.org/pypi/grapefruit/
   :alt: Latest PyPI version

.. image:: https://img.shields.io/travis/xav/Grapefruit/master.svg
   :target: https://travis-ci.org/xav/grapefruit/
   :alt: Travis CI build status

.. image:: https://coveralls.io/repos/github/xav/Grapefruit/badge.svg?branch=master
   :target: https://coveralls.io/github/xav/Grapefruit?branch=master
   :alt: Test coverage


GrapeFruit is a pure Python module that let you easily manipulate and convert color information.
Its Primary goal is to be *natural* and *flexible*.

The following color systems are supported by GrapeFruit:
  * RGB (sRGB)
  * HSL
  * HSV
  * YIQ
  * YUV
  * CIE-XYZ
  * CIE-LAB (with the illuminant you want)
  * CMY
  * CMYK
  * HTML/CSS color definition (#RRGGBB, #RGB or the X11 color name)
  * RYB (artistic color wheel


License
=========

::

  Copyright (c) 2008, Xavier Basty

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
